@@ -1,7 +1,7 @@
 /* -*- mode:C; coding:utf-8 -*- */
 /*  This file is part of MED.
  *
- *  COPYRIGHT (C) 1999 - 2019  EDF R&D, CEA/DEN
+ *  COPYRIGHT (C) 1999 - 2020  EDF R&D, CEA/DEN
  *  MED is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation, either version 3 of the License, or
@@ -29,10 +29,10 @@ extern "C" {
 #endif
 
 /* This is the minimum hdf version med must have  */
-#define HDF_VERSION_REF 1.12.0
+#define HDF_VERSION_REF "1.12.1"
 #define HDF_VERSION_MAJOR_REF 1
 #define HDF_VERSION_MINOR_REF 12
-#define HDF_VERSION_RELEASE_REF 0
+#define HDF_VERSION_RELEASE_REF 1
 #define HDF_VERSION_NUM_REF (HDF_VERSION_MAJOR_REF * 10000 + HDF_VERSION_MINOR_REF * 100  + HDF_VERSION_RELEASE_REF )
 
 #define HDF5_VERSION (H5_VERS_MAJOR * 10000 + H5_VERS_MINOR * 100  + H5_VERS_RELEASE )
@@ -55,13 +55,15 @@ extern "C" {
 
 /*En anglais*/
 #define MED_MAJOR_NUM 4
-#define MED_MINOR_NUM 0
+#define MED_MINOR_NUM 1
 #define MED_RELEASE_NUM 0
 #define MED_3_LATEST_MINOR 3
-#define MED_4_LATEST_MINOR 0
+#define MED_4_LATEST_MINOR 1
+#define MED_40_LATEST_RELEASE 1
+
 /*En franglais*/
 #define MED_NUM_MAJEUR 4
-#define MED_NUM_MINEUR 0
+#define MED_NUM_MINEUR 1
 #define MED_NUM_RELEASE 0
 
 #define STR(x) #x
@@ -152,6 +154,7 @@ typedef enum {MED_COORDINATE, MED_CONNECTIVITY, MED_NAME, MED_NUMBER,  MED_FAMIL
 /* 2.3v3.0 ok*/
 /** \internal*/
 typedef enum {MED_INTERNAL_FLOAT32=4, MED_INTERNAL_FLOAT64=6,
+	      MED_INTERNAL_INT8=20,
 	      MED_INTERNAL_INT32=24 , MED_INTERNAL_INT64=26, MED_INTERNAL_INT=28,
 	      MED_INTERNAL_NAME=30  , MED_INTERNAL_SNAME=32,
 	      MED_INTERNAL_LNAME=34 , MED_INTERNAL_IDENT=38,
@@ -296,15 +299,17 @@ typedef enum {MED_FALSE, MED_TRUE} med_bool ;
 #define MED_UNDEF_SIZE 0
 #define MED_NO_PROFILE_SIZE 0  /**<Fourni une valeur de taille de profil par défaut d'utilisation de la notion de profil.*/
 
-typedef enum {MED_SORT_DTIT,MED_SORT_ITDT,MED_SORT_UNDEF=-1 } med_sorting_type; /**<Indique l'ordre de tri des séquences de calcul d'un maillage.
+typedef enum {MED_SORT_DTIT,MED_SORT_ITDT,MED_SORT_UNDEF=-1 } med_sorting_type; /**<Indique l'ordre de tri des étapes de calcul d'un maillage.
                                                                                     Cette ordre, fixé à la création du maillage 
 										    est important pour comparer l'évolution du maillage
-                                                                                    d'une séquence de calcul à une autre.
+                                                                                    d'une étape de calcul à une autre.
 										    Utilisé conjointement avec les profils, 
 										    il permet de réduire les écritures aux 
 										    seules informations modifiées  par rapport 
-										    à la séquence de calcul précédente. */
+										    à l'étape de calcul précédente. */
 
+#define MED_ALL_DT -2 /**<Indique que l'on selectionne toutes les dates.*/
+#define MED_ALL_IT -2 /**<Indique que l'on selectionne toutes les itérations.*/
 #define MED_NO_DT -1 /**<Indique que l'on n'utilise pas la notion de date.*/
 #define MED_NO_IT -1 /**<Indique que l'on n'utilise pas la notion d'itération.*/
 #define MED_UNDEF_DT 0 /**<Fourni une valeur de date par défaut d'utilisation de la notion de date.*/
@@ -422,6 +427,21 @@ extern MEDC_EXPORT med_geometry_type MED_GET_EDGE_GEOMETRY_TYPE[MED_N_EDGE_FIXED
 extern MEDC_EXPORT const char * MED_GET_EDGE_GEOMETRY_TYPENAME[MED_N_EDGE_FIXED_GEO+2];
 extern MEDC_EXPORT med_geometry_type MED_GET_NODE_GEOMETRY_TYPE[MED_N_NODE_FIXED_GEO+2];
 extern MEDC_EXPORT const char * MED_GET_NODE_GEOMETRY_TYPENAME[MED_N_NODE_FIXED_GEO+2];
+extern MEDC_EXPORT const med_geometry_type * const MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE[MED_N_ENTITY_TYPES+2];
+#define MED_GET_GEOMETRY_TYPE_IT_FROM_ENTITY_TYPE_IT MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
+extern MEDC_EXPORT const int MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT[MED_N_ENTITY_TYPES+2];
+
+  
+/* Itérateurs sur les types d'entité et types géométriques */
+extern MEDC_EXPORT int                 MEDgetEntityTypeIt         (med_entity_type   entitytype);
+extern MEDC_EXPORT int                 MEDgetCellGeometryTypeIt   (med_geometry_type geotype   );
+extern MEDC_EXPORT int                 MEDgetFaceGeometryTypeIt   (med_geometry_type geotype   );
+extern MEDC_EXPORT int                 MEDgetEdgeGeometryTypeIt   (med_geometry_type geotype   );
+extern MEDC_EXPORT int                 MEDgetNodeGeometryTypeIt   (med_geometry_type geotype   );
+extern MEDC_EXPORT int                 MEDgetEntityGeometryTypeIt (med_entity_type   entitytype, med_geometry_type geotype);
+/**/
+extern MEDC_EXPORT const char * const  MEDgetGeometryTypeName     (med_geometry_type geotype   );
+extern MEDC_EXPORT const char * const  MEDgetEntityTypeName       (med_entity_type   entitytype);
 
 /*      Predefined names for struct elements            */
 #define MED_PARTICLE_NAME   "MED_PARTICLE"
